@@ -1,40 +1,26 @@
-/*
-libdmtx - Data Matrix Encoding/Decoding Library
-
-Copyright (C) 2008, 2009 Mike Laughton
-
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) any later version.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library; if not, write to the Free Software
-Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
-Contact: mike@dragonflylogic.com
-*/
-
-/* $Id: dmtxregion.c 755 2009-02-26 05:20:06Z mblaughton $ */
+/**
+ * libdmtx - Data Matrix Encoding/Decoding Library
+ * Copyright 2008, 2009 Mike Laughton. All rights reserved.
+ * Copyright 2012-2016 Vadim A. Misbakh-Soloviov. All rights reserved.
+ * Copyright 2016 Tim Zaman. All rights reserved.
+ *
+ * See LICENSE file in the main project directory for full
+ * terms of use and distribution.
+ *
+ * Contact:
+ * Vadim A. Misbakh-Soloviov <dmtx@mva.name>
+ * Mike Laughton <mike@dragonflylogic.com>
+ *
+ * \file dmtxregion.c
+ * \brief Detect barcode regions
+ */
 
 #define DMTX_HOUGH_RES 180
 
 /**
- * @file dmtxregion.c
- * @brief Detect barcode regions
- *
- * This file contains region detection logic.
- */
-
-/**
- * @brief  Create copy of existing region struct
- * @param  None
- * @return Initialized DmtxRegion struct
+ * \brief  Create copy of existing region struct
+ * \param  None
+ * \return Initialized DmtxRegion struct
  */
 extern DmtxRegion *
 dmtxRegionCreate(DmtxRegion *reg)
@@ -51,9 +37,9 @@ dmtxRegionCreate(DmtxRegion *reg)
 }
 
 /**
- * @brief  Destroy region struct
- * @param  reg
- * @return void
+ * \brief  Destroy region struct
+ * \param  reg
+ * \return void
  */
 extern DmtxPassFail
 dmtxRegionDestroy(DmtxRegion **reg)
@@ -69,10 +55,10 @@ dmtxRegionDestroy(DmtxRegion **reg)
 }
 
 /**
- * @brief  Find next barcode region
- * @param  dec Pointer to DmtxDecode information struct
- * @param  timeout Pointer to timeout time (NULL if none)
- * @return Detected region (if found)
+ * \brief  Find next barcode region
+ * \param  dec Pointer to DmtxDecode information struct
+ * \param  timeout Pointer to timeout time (NULL if none)
+ * \return Detected region (if found)
  */
 extern DmtxRegion *
 dmtxRegionFindNext(DmtxDecode *dec, DmtxTime *timeout)
@@ -101,10 +87,10 @@ dmtxRegionFindNext(DmtxDecode *dec, DmtxTime *timeout)
 }
 
 /**
- * @brief  Scan individual pixel for presence of barcode edge
- * @param  dec Pointer to DmtxDecode information struct
- * @param  loc Pixel location
- * @return Detected region (if any)
+ * \brief  Scan individual pixel for presence of barcode edge
+ * \param  dec Pointer to DmtxDecode information struct
+ * \param  loc Pixel location
+ * \return Detected region (if any)
  */
 extern DmtxRegion *
 dmtxRegionScanPixel(DmtxDecode *dec, int x, int y)
@@ -126,33 +112,33 @@ dmtxRegionScanPixel(DmtxDecode *dec, int x, int y)
 
    /* Test for presence of any reasonable edge at this location */
    flowBegin = MatrixRegionSeekEdge(dec, loc);
-   if(flowBegin.mag < 10)
+   if(flowBegin.mag < (int)(dec->edgeThresh * 7.65 + 0.5))
       return NULL;
 
    memset(&reg, 0x00, sizeof(DmtxRegion));
 
    /* Determine barcode orientation */
-   if(MatrixRegionOrientation(dec, &reg, flowBegin) != DmtxPass)
+   if(MatrixRegionOrientation(dec, &reg, flowBegin) == DmtxFail)
       return NULL;
-   if(dmtxRegionUpdateXfrms(dec, &reg) != DmtxPass)
+   if(dmtxRegionUpdateXfrms(dec, &reg) == DmtxFail)
       return NULL;
 
    /* Define top edge */
-   if(MatrixRegionAlignCalibEdge(dec, &reg, DmtxEdgeTop) != DmtxPass)
+   if(MatrixRegionAlignCalibEdge(dec, &reg, DmtxEdgeTop) == DmtxFail)
       return NULL;
-   if(dmtxRegionUpdateXfrms(dec, &reg) != DmtxPass)
+   if(dmtxRegionUpdateXfrms(dec, &reg) == DmtxFail)
       return NULL;
 
    /* Define right edge */
-   if(MatrixRegionAlignCalibEdge(dec, &reg, DmtxEdgeRight) != DmtxPass)
+   if(MatrixRegionAlignCalibEdge(dec, &reg, DmtxEdgeRight) == DmtxFail)
       return NULL;
-   if(dmtxRegionUpdateXfrms(dec, &reg) != DmtxPass)
+   if(dmtxRegionUpdateXfrms(dec, &reg) == DmtxFail)
       return NULL;
 
    CALLBACK_MATRIX(&reg);
 
    /* Calculate the best fitting symbol size */
-   if(MatrixRegionFindSize(dec, &reg) != DmtxPass)
+   if(MatrixRegionFindSize(dec, &reg) == DmtxFail)
       return NULL;
 
    /* Found a valid matrix region */
@@ -595,19 +581,18 @@ RightAngleTrueness(DmtxVector2 c0, DmtxVector2 c1, DmtxVector2 c2, double angle)
 }
 
 /**
- * @brief  Read color of Data Matrix module location
- * @param  dec
- * @param  reg
- * @param  symbolRow
- * @param  symbolCol
- * @param  sizeIdx
- * @return Averaged module color
+ * \brief  Read color of Data Matrix module location
+ * \param  dec
+ * \param  reg
+ * \param  symbolRow
+ * \param  symbolCol
+ * \param  sizeIdx
+ * \return Averaged module color
  */
 static int
 ReadModuleColor(DmtxDecode *dec, DmtxRegion *reg, int symbolRow, int symbolCol,
       int sizeIdx, int colorPlane)
 {
-   int err;
    int i;
    int symbolRows, symbolCols;
    int color, colorTmp;
@@ -626,19 +611,21 @@ ReadModuleColor(DmtxDecode *dec, DmtxRegion *reg, int symbolRow, int symbolCol,
 
       dmtxMatrix3VMultiplyBy(&p, reg->fit2raw);
 
-      err = dmtxDecodeGetPixelValue(dec, (int)(p.X + 0.5), (int)(p.Y + 0.5),
+      //fprintf(stdout, "%dx%d\n", (int)(p.X + 0.5), (int)(p.Y + 0.5));
+
+      dmtxDecodeGetPixelValue(dec, (int)(p.X + 0.5), (int)(p.Y + 0.5),
             colorPlane, &colorTmp);
       color += colorTmp;
    }
-
+   //fprintf(stdout, "\n");
    return color/5;
 }
 
 /**
- * @brief  Determine barcode size, expressed in modules
- * @param  image
- * @param  reg
- * @return DmtxPass | DmtxFail
+ * \brief  Determine barcode size, expressed in modules
+ * \param  image
+ * \param  reg
+ * \return DmtxPass | DmtxFail
  */
 static DmtxPassFail
 MatrixRegionFindSize(DmtxDecode *dec, DmtxRegion *reg)
@@ -652,9 +639,9 @@ MatrixRegionFindSize(DmtxDecode *dec, DmtxRegion *reg)
    int colorOnAvg, bestColorOnAvg;
    int colorOffAvg, bestColorOffAvg;
    int contrast, bestContrast;
-   DmtxImage *img;
+//   DmtxImage *img;
 
-   img = dec->image;
+//   img = dec->image;
    bestSizeIdx = DmtxUndefined;
    bestContrast = 0;
    bestColorOnAvg = bestColorOffAvg = 0;
@@ -774,13 +761,13 @@ MatrixRegionFindSize(DmtxDecode *dec, DmtxRegion *reg)
 }
 
 /**
- * @brief  Count the number of number of transitions between light and dark
- * @param  img
- * @param  reg
- * @param  xStart
- * @param  yStart
- * @param  dir
- * @return Jump count
+ * \brief  Count the number of number of transitions between light and dark
+ * \param  img
+ * \param  reg
+ * \param  xStart
+ * \param  yStart
+ * \param  dir
+ * \return Jump count
  */
 static int
 CountJumpTally(DmtxDecode *dec, DmtxRegion *reg, int xStart, int yStart, DmtxDirection dir)
@@ -1217,6 +1204,8 @@ TrailBlazeGapped(DmtxDecode *dec, DmtxRegion *reg, DmtxBresLine line, int stream
             break;
 
          err = BresLineGetStep(line, flowNext.loc, &travel, &outward);
+         if (err == DmtxFail) { return DmtxFail; }
+
          if(flowNext.mag < 50 || outward < 0 || (outward == 0 && travel < 0)) {
             onEdge = DmtxFalse;
          }
@@ -1321,6 +1310,8 @@ FindBestSolidLine(DmtxDecode *dec, DmtxRegion *reg, int step0, int step1, int st
    angleBest = 0;
    hOffset = hOffsetBest = 0;
 
+   sign = 0;
+
    /* Always follow path flowing away from the trail start */
    if(step0 != 0) {
       if(step0 > 0) {
